==> ui-framework-4.14.8-sources.jar: io/intino/alexandria/ui/resources/WidgetTypeResource.java <==
package io.intino.alexandria.ui.resources;

import io.intino.alexandria.UiFrameworkBox;
import io.intino.alexandria.ui.pages.WidgetTypePage;
import io.intino.alexandria.exceptions.AlexandriaException;
import io.intino.alexandria.ui.displays.notifiers.DisplayNotifierProvider;

import java.util.Base64;
import java.util.UUID;
import java.util.function.Consumer;
import java.util.function.Function;

public class WidgetTypeResource extends io.intino.alexandria.ui.spark.resources.Resource {
	private final UiFrameworkBox box;

	public WidgetTypeResource(UiFrameworkBox box, io.intino.alexandria.ui.spark.UISparkManager manager, DisplayNotifierProvider notifierProvider) {
		super(manager, notifierProvider);
		this.box = box;
	}

	@Override
	public void execute() throws AlexandriaException {
		super.execute();
		fillDeviceParameter();
		render();
	}

	private void render() {
		String clientId = UUID.randomUUID().toString();
		WidgetTypePage page = new WidgetTypePage();
		page.session = manager.currentSession();
		page.session.browser().onRedirect(location -> manager.redirect(location));
		page.session.browser().requestUrl(manager.requestUrl());
		page.session.whenLogin(new Function<String, String>() {
			@Override
			public String apply(String baseUrl) {
				return WidgetTypeResource.this.authenticate(page.session, baseUrl);
			}
		});
		page.session.whenLogout(b -> logout(page.session));
		page.box = box;
		page.clientId = clientId;
		page.googleApiKey = "AIzaSyA8FjeAX36umrYD8Jk2FbRFWqDEulInKIA";
		page.device = parameterValue("device");
		page.token = parameterValue("token");
		page.type = parameterValue("type");
        if (!page.hasPermissions()) {
            manager.redirect(page.redirectUrl());
            return;
        }

		manager.pushService().onOpen(client -> {
			if (!client.id().equals(page.clientId))
				return false;

			if (client.soul() != null) {
				((io.intino.alexandria.ui.displays.RouteDispatcher)box.routeManager().routeDispatcher()).dispatchWidgetType(client.soul(), page.type);
				return false;
			}

			io.intino.alexandria.ui.Soul soul = page.prepareSoul(client);
			soul.onRedirect((location) -> manager.redirect(location));
			soul.addRegisterDisplayListener(display -> {
				display.inject(notifier(page.session, client, display));
				display.inject(page.session);
				display.inject(soul);
				display.inject(() -> soul);
			});
			client.soul(soul);
			client.cookies(manager.cookies());

			box.registerSoul(clientId, soul);
			soul.register(new io.intino.alexandria.ui.displays.DisplayRouter(box).id("__router__"));
			((io.intino.alexandria.ui.displays.RouteDispatcher)box.routeManager().routeDispatcher()).dispatchWidgetType(soul, page.type);

			return true;
		});

		manager.pushService().onClose(clientId).execute(new Consumer<io.intino.alexandria.ui.services.push.UIClient>() {
			@Override
			public void accept(io.intino.alexandria.ui.services.push.UIClient client) {
				box.soul(client.id()).ifPresent(s -> s.destroy());
				box.unRegisterSoul(client.id());
				manager.unRegister(client);
			}
		});

		manager.write(page.execute());
	}

}

==> ui-framework-5.2.1-sources.jar: io/intino/alexandria/ui/resources/WidgetTypeResource.java <==
package io.intino.alexandria.ui.resources;

import io.intino.alexandria.UiFrameworkBox;
import io.intino.alexandria.ui.pages.WidgetTypeMobilePage;
import io.intino.alexandria.ui.pages.WidgetTypePage;
import io.intino.alexandria.exceptions.AlexandriaException;
import io.intino.alexandria.ui.displays.notifiers.DisplayNotifierProvider;
import io.intino.alexandria.ui.spark.pages.UiPage;

import java.util.Base64;
import java.util.UUID;
import java.util.function.Consumer;
import java.util.function.Function;

public class WidgetTypeResource extends io.intino.alexandria.ui.spark.resources.Resource {
	private final UiFrameworkBox box;

	public WidgetTypeResource(UiFrameworkBox box, io.intino.alexandria.ui.spark.UISparkManager manager, DisplayNotifierProvider notifierProvider) {
		super(manager, notifierProvider);
		this.box = box;
	}

	@Override
	public void execute() throws AlexandriaException {
		super.execute();
		fillDeviceParameter();
		render();
	}

	private void render() {
		String clientId = UUID.randomUUID().toString();
		UiPage page = manager.fromQuery("device") != null ? new WidgetTypeMobilePage() : new WidgetTypePage();
		page.session = manager.currentSession();
		page.session.browser().onRedirect(location -> manager.redirect(location));
		page.session.browser().requestUrl(manager.requestUrl());
		page.session.whenLogin(new Function<String, String>() {
			@Override
			public String apply(String baseUrl) {
				return WidgetTypeResource.this.authenticate(page.session, baseUrl);
			}
		});
		page.session.whenLogout(b -> logout(page.session));
        if (page instanceof WidgetTypeMobilePage) ((WidgetTypeMobilePage)page).box = box;
        else ((WidgetTypePage)page).box = box;
		page.clientId = clientId;
		page.googleApiKey = "AIzaSyA8FjeAX36umrYD8Jk2FbRFWqDEulInKIA";
		page.device = parameterValue("device");
		page.token = parameterValue("token");
		if (page instanceof WidgetTypeMobilePage) ((WidgetTypeMobilePage)page).type = parameterValue("type");
		else ((WidgetTypePage)page).type = parameterValue("type");
		if (!page.hasPermissions()) {
			manager.redirect(page.redirectUrl());
			return;
		}

		manager.pushService().onOpen(client -> {
			if (!client.id().equals(page.clientId))
				return false;

			if (client.soul() != null) {
				((io.intino.alexandria.ui.displays.RouteDispatcher)box.routeManager().routeDispatcher()).dispatchWidgetType(client.soul(), page instanceof WidgetTypeMobilePage ? ((WidgetTypeMobilePage)page).type : ((WidgetTypePage)page).type);
				return false;
			}

			io.intino.alexandria.ui.Soul soul = page.prepareSoul(client);
			soul.onRedirect((location) -> manager.redirect(location));
			soul.addRegisterDisplayListener(display -> {
				display.inject(notifier(page.session, client, display));
				display.inject(page.session);
				display.inject(soul);
				display.inject(() -> soul);
			});
			client.soul(soul);
			client.cookies(manager.cookies());

			box.registerSoul(clientId, soul);
			soul.register(new io.intino.alexandria.ui.displays.DisplayRouter(box).id("__router__"));
			((io.intino.alexandria.ui.displays.RouteDispatcher)box.routeManager().routeDispatcher()).dispatchWidgetType(soul, page instanceof WidgetTypeMobilePage ? ((WidgetTypeMobilePage)page).type : ((WidgetTypePage)page).type);

			return true;
		});

		manager.pushService().onClose(clientId).execute(new Consumer<io.intino.alexandria.ui.services.push.UIClient>() {
			@Override
			public void accept(io.intino.alexandria.ui.services.push.UIClient client) {
				box.soul(client.id()).ifPresent(s -> s.destroy());
				box.unRegisterSoul(client.id());
				manager.unRegister(client);
			}
		});

		manager.write(page.execute());
	}

}
